# nonebot_plugin_easyCommand
 一个基于NoneBot2的简单的用来扩充命令或添加定时任务的插件

一、概述

1.起始符+"添加命令 标题 内容","删除命令 标题","查看命令","允许命令","结束命令"，"获取CQ"分达到如其字意的效果

2.添加命令后当接收到命令后会自动匹配命令

3."允许命令","结束命令"默认不开放群无起始符命令白名单，且不存录，为超级管理员游戏做

4.群聊@、白名单、第一个字符为命令起始符且全部匹配(避免响应其他未加锁插件) 匹配回复，私聊不加起始符匹配回复或加且全部匹配

5.起始符+"注册定时 时间 标题 内容" "删除定时 标题"


二、详解

1.添加命令 标题 内容 内容支持图像、表情、转发、文本

2.删除命令 标题 不支持图像类型的标题 第一顺位超管输入"#+-*/真的啦已经确认过啦"删除所有命令

3.查看命令 超管输入命令"查看命令全"查看所有命令、普通用户查看自己写的命令，最长皆为前3-400字符长度  如想要都可以全查自行删除约136行处 and uid in superList

4.允许命令 群聊添加当前群聊或私聊添加当前私聊者到无需前缀命令起始符响应白名单 权限为超管 可自行修改代码剥离允许权限列表为群管可添加

5.结束命令 同上

6.获取CQ 当前聊天者可获取一次返回CQ码的机会，下次消息触发

7.注册定时 时间 标题 内容 时间格式为时.分.秒 遵循corn规则，但表达式仅限于d */d d-d * ，其中d指时间实例如9、*/2、10-59、* 
内容支持同上支持CQ，都不支持视频CQ 

8.删除定时 标题
